@@ -66,6 +66,10 @@ chomp (gchar *s)
 	}
 }
 
+#ifdef GIT_SSH
+static gboolean tried_ssh_key = FALSE;
+#endif
+
 static GgitCred *
 cloner_credentials (GgitRemoteCallbacks  *callbacks,
                     const gchar          *url,
@@ -80,6 +84,14 @@ cloner_credentials (GgitRemoteCallbacks  *callbacks,
 
 	g_return_val_if_fail (error != NULL && *error == NULL, NULL);
 
+#ifdef GIT_SSH
+	if ((allowed_types & GGIT_CREDTYPE_SSH_KEY) != 0 && !tried_ssh_key)
+	{
+		tried_ssh_key = TRUE;
+		return GGIT_CRED (ggit_cred_ssh_key_from_agent_new (username_from_url, error));
+	}
+#endif
+
 	g_printf ("Username: ");
 
 	if (fgets (username, sizeof (username) - 1, stdin) == NULL)
@@ -186,6 +198,6 @@ int main(int argc, char **argv)
 		g_object_unref (cloned_repo);
 	}
 
-	ggit_clone_options_free (options);
+	g_object_unref (options);
 	return 0;
 }
