@@ -27,27 +27,14 @@
 
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-types.h>
+#include <libgit2-glib/ggit-tree.h>
+#include <libgit2-glib/ggit-commit-parents.h>
+#include <libgit2-glib/ggit-signature.h>
 
 G_BEGIN_DECLS
 
-#define GGIT_TYPE_COMMIT		(ggit_commit_get_type ())
-#define GGIT_COMMIT(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GGIT_TYPE_COMMIT, GgitCommit))
-#define GGIT_COMMIT_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GGIT_TYPE_COMMIT, GgitCommitClass))
-#define GGIT_IS_COMMIT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GGIT_TYPE_COMMIT))
-#define GGIT_IS_COMMIT_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GGIT_TYPE_COMMIT))
-#define GGIT_COMMIT_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GGIT_TYPE_COMMIT, GgitCommitClass))
-
-typedef struct _GgitCommitClass		GgitCommitClass;
-typedef struct _GgitCommitPrivate	GgitCommitPrivate;
-
-struct _GgitCommit
-{
-	/*< private >*/
-	GgitObject parent;
-
-	/* priv padding */
-	GgitCommitPrivate *priv;
-};
+#define GGIT_TYPE_COMMIT (ggit_commit_get_type ())
+G_DECLARE_DERIVABLE_TYPE (GgitCommit, ggit_commit, GGIT, COMMIT, GgitObject)
 
 /**
  * GgitCommitClass:
@@ -61,9 +48,6 @@ struct _GgitCommitClass
 	GgitObjectClass parent_class;
 };
 
-GType                ggit_commit_get_type             (void) G_GNUC_CONST;
-GType                ggit_commit_parents_get_type     (void) G_GNUC_CONST;
-
 GgitCommit          *_ggit_commit_wrap                (git_commit        *commit,
                                                        gboolean           owned);
 
@@ -79,19 +63,6 @@ GgitSignature       *ggit_commit_get_author           (GgitCommit        *commit
 
 GgitCommitParents   *ggit_commit_get_parents          (GgitCommit        *commit);
 
-
-
-GgitCommitParents   *ggit_commit_parents_ref          (GgitCommitParents *parents);
-void                 ggit_commit_parents_unref        (GgitCommitParents *parents);
-
-guint                ggit_commit_parents_size         (GgitCommitParents *parents);
-
-GgitCommit          *ggit_commit_parents_get          (GgitCommitParents *parents,
-                                                       guint              idx);
-
-GgitOId             *ggit_commit_parents_get_id       (GgitCommitParents *parents,
-                                                       guint              idx);
-
 GgitTree            *ggit_commit_get_tree             (GgitCommit        *commit);
 
 GgitOId             *ggit_commit_get_tree_id          (GgitCommit        *commit);
