@@ -23,6 +23,7 @@
 #include <git2.h>
 
 #include "ggit-diff.h"
+#include "ggit-diff-binary.h"
 #include "ggit-diff-delta.h"
 #include "ggit-diff-options.h"
 #include "ggit-diff-line.h"
@@ -34,13 +35,18 @@
 #include "ggit-diff-find-options.h"
 #include "ggit-diff-format-email-options.h"
 
-#define GGIT_DIFF_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GGIT_TYPE_DIFF, GgitDiffPrivate))
 
-struct _GgitDiffPrivate
+/**
+ * GgitDiff:
+ *
+ * Represents a diff list.
+ */
+
+typedef struct _GgitDiffPrivate
 {
 	GgitRepository *repository;
 	gchar *encoding;
-};
+} GgitDiffPrivate;
 
 typedef struct {
 	GgitDiff *diff;
@@ -49,11 +55,12 @@ typedef struct {
 	gpointer user_data;
 
 	GgitDiffFileCallback file_cb;
+	GgitDiffBinaryCallback binary_cb;
 	GgitDiffHunkCallback hunk_cb;
 	GgitDiffLineCallback line_cb;
 } CallbackWrapperData;
 
-G_DEFINE_TYPE (GgitDiff, ggit_diff, GGIT_TYPE_NATIVE)
+G_DEFINE_TYPE_WITH_PRIVATE (GgitDiff, ggit_diff, GGIT_TYPE_NATIVE)
 
 enum
 {
@@ -76,8 +83,11 @@ ggit_diff_file_callback_wrapper (const git_diff_delta *delta,
 
 	if (data->diff != NULL)
 	{
+		GgitDiffPrivate *priv;
 		GgitDiffFile *file;
 
+		priv = ggit_diff_get_instance_private (data->diff);
+
 		if (ggit_diff_delta_get_status (gdelta) == GGIT_DELTA_DELETED)
 		{
 			file = ggit_diff_delta_get_old_file (gdelta);
@@ -94,7 +104,7 @@ ggit_diff_file_callback_wrapper (const git_diff_delta *delta,
 			path = ggit_diff_file_get_path (file);
 
 			data->encoding =
-				ggit_repository_get_attribute (data->diff->priv->repository,
+				ggit_repository_get_attribute (priv->repository,
 			                                       path,
 			                                       "encoding",
 			                                       GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX,
@@ -109,6 +119,27 @@ ggit_diff_file_callback_wrapper (const git_diff_delta *delta,
 	return ret;
 }
 
+static gint
+ggit_diff_binary_callback_wrapper (const git_diff_delta  *delta,
+                                   const git_diff_binary *binary,
+                                   gpointer               user_data)
+{
+	CallbackWrapperData *data = user_data;
+	GgitDiffDelta *gdelta;
+	GgitDiffBinary *gbinary;
+	gint ret;
+
+	gdelta = _ggit_diff_delta_wrap (delta);
+	gbinary = _ggit_diff_binary_wrap (binary);
+
+	ret = data->binary_cb (gdelta, gbinary, data->user_data);
+
+	ggit_diff_delta_unref (gdelta);
+	ggit_diff_binary_unref (gbinary);
+
+	return ret;
+}
+
 static gint
 ggit_diff_hunk_callback_wrapper (const git_diff_delta *delta,
                                  const git_diff_hunk  *hunk,
@@ -149,7 +180,10 @@ ggit_diff_line_callback_wrapper (const git_diff_delta *delta,
 	}
 	else if (data->diff != NULL)
 	{
-		encoding = data->diff->priv->encoding;
+		GgitDiffPrivate *priv;
+
+		priv = ggit_diff_get_instance_private (data->diff);
+		encoding = priv->encoding;
 	}
 
 	gdelta = _ggit_diff_delta_wrap (delta);
@@ -176,7 +210,10 @@ ggit_diff_line_callback_wrapper (const git_diff_delta *delta,
 static void
 ggit_diff_finalize (GObject *object)
 {
-	GgitDiffPrivate *priv = GGIT_DIFF (object)->priv;
+	GgitDiff *diff = GGIT_DIFF (object);
+	GgitDiffPrivate *priv;
+
+	priv = ggit_diff_get_instance_private (diff);
 
 	g_free (priv->encoding);
 
@@ -189,12 +226,15 @@ ggit_diff_set_property (GObject      *object,
                         const GValue *value,
                         GParamSpec   *pspec)
 {
-	GgitDiff *self = GGIT_DIFF (object);
+	GgitDiff *diff = GGIT_DIFF (object);
+	GgitDiffPrivate *priv;
+
+	priv = ggit_diff_get_instance_private (diff);
 
 	switch (prop_id)
 	{
 		case PROP_REPOSITORY:
-			self->priv->repository = g_value_dup_object (value);
+			priv->repository = g_value_dup_object (value);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -208,12 +248,15 @@ ggit_diff_get_property (GObject    *object,
                         GValue     *value,
                         GParamSpec *pspec)
 {
-	GgitDiff *self = GGIT_DIFF (object);
+	GgitDiff *diff = GGIT_DIFF (object);
+	GgitDiffPrivate *priv;
+
+	priv = ggit_diff_get_instance_private (diff);
 
 	switch (prop_id)
 	{
 		case PROP_REPOSITORY:
-			g_value_set_object (value, self->priv->repository);
+			g_value_set_object (value, priv->repository);
 			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -224,9 +267,12 @@ ggit_diff_get_property (GObject    *object,
 static void
 ggit_diff_constructed (GObject *object)
 {
-	GgitDiffPrivate *priv = GGIT_DIFF (object)->priv;
+	GgitDiff *diff = GGIT_DIFF (object);
+	GgitDiffPrivate *priv;
 	GgitConfig *config = NULL;
 
+	priv = ggit_diff_get_instance_private (diff);
+
 	if (priv->repository != NULL)
 	{
 		config = ggit_repository_get_config (priv->repository, NULL);
@@ -267,14 +313,11 @@ ggit_diff_class_init (GgitDiffClass *klass)
 	                                                      G_PARAM_READWRITE |
 	                                                      G_PARAM_CONSTRUCT_ONLY |
 	                                                      G_PARAM_STATIC_STRINGS));
-
-	g_type_class_add_private (object_class, sizeof (GgitDiffPrivate));
 }
 
 static void
 ggit_diff_init (GgitDiff *self)
 {
-	self->priv = GGIT_DIFF_GET_PRIVATE (self);
 }
 
 static GgitDiff *
@@ -497,6 +540,8 @@ ggit_diff_merge (GgitDiff  *onto,
  * @diff: a #GgitDiff.
  * @file_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffFileCallback.
+ * @binary_cb: (allow-none) (scope call) (closure user_data):
+ *  a #GgitDiffBinaryCallback.
  * @hunk_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffHunkCallback.
  * @line_cb: (allow-none) (scope call) (closure user_data):
@@ -504,11 +549,12 @@ ggit_diff_merge (GgitDiff  *onto,
  * @user_data: callback user data.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Iterates over the diff calling @file_cb, @hunk_cb and @line_cb.
+ * Iterates over the diff calling @file_cb, @binary_cb, @hunk_cb and @line_cb.
  */
 void
 ggit_diff_foreach (GgitDiff              *diff,
                    GgitDiffFileCallback   file_cb,
+                   GgitDiffBinaryCallback binary_cb,
                    GgitDiffHunkCallback   hunk_cb,
                    GgitDiffLineCallback   line_cb,
                    gpointer              *user_data,
@@ -517,11 +563,12 @@ ggit_diff_foreach (GgitDiff              *diff,
 	gint ret;
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
+	git_diff_binary_cb real_binary_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
 	git_diff_line_cb real_line_cb = NULL;
 
 	g_return_if_fail (GGIT_IS_DIFF (diff));
-	g_return_if_fail (file_cb != NULL && hunk_cb != NULL && line_cb != NULL);
+	g_return_if_fail (file_cb != NULL && binary_cb != NULL && hunk_cb != NULL && line_cb != NULL);
 	g_return_if_fail (error == NULL || *error == NULL);
 
 	wrapper_data.user_data = user_data;
@@ -534,6 +581,12 @@ ggit_diff_foreach (GgitDiff              *diff,
 		wrapper_data.file_cb = file_cb;
 	}
 
+	if (binary_cb != NULL)
+	{
+		real_binary_cb = ggit_diff_binary_callback_wrapper;
+		wrapper_data.binary_cb = binary_cb;
+	}
+
 	if (hunk_cb != NULL)
 	{
 		real_hunk_cb = ggit_diff_hunk_callback_wrapper;
@@ -547,7 +600,8 @@ ggit_diff_foreach (GgitDiff              *diff,
 	}
 
 	ret = git_diff_foreach (_ggit_native_get (diff),
-	                        real_file_cb, real_hunk_cb, real_line_cb,
+	                        real_file_cb, real_binary_cb,
+	                        real_hunk_cb, real_line_cb,
 	                        &wrapper_data);
 
 	if (ret != GIT_OK)
@@ -663,6 +717,8 @@ ggit_diff_get_num_deltas (GgitDiff *diff)
  * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @file_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffFileCallback.
+ * @binary_cb: (allow-none) (scope call) (closure user_data):
+ *  a #GgitDiffBinaryCallback.
  * @hunk_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffHunkCallback.
  * @line_cb: (allow-none) (scope call) (closure user_data):
@@ -670,7 +726,7 @@ ggit_diff_get_num_deltas (GgitDiff *diff)
  * @user_data: callback user data.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Iterates over the diff calling @file_cb, @hunk_cb and @line_cb.
+ * Iterates over the diff calling @file_cb, @binary_cb, @hunk_cb and @line_cb.
  *
  * The #GgitDiffFile mode always be 0, path will be %NULL and when a blob is
  * %NULL the oid will be 0.
@@ -685,6 +741,7 @@ ggit_diff_blobs (GgitBlob              *old_blob,
                  const gchar           *new_as_path,
                  GgitDiffOptions       *diff_options,
                  GgitDiffFileCallback   file_cb,
+                 GgitDiffBinaryCallback binary_cb,
                  GgitDiffHunkCallback   hunk_cb,
                  GgitDiffLineCallback   line_cb,
                  gpointer              *user_data,
@@ -694,6 +751,7 @@ ggit_diff_blobs (GgitBlob              *old_blob,
 	const git_diff_options *gdiff_options;
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
+	git_diff_binary_cb real_binary_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
 	git_diff_line_cb real_line_cb = NULL;
 
@@ -711,6 +769,12 @@ ggit_diff_blobs (GgitBlob              *old_blob,
 		wrapper_data.file_cb = file_cb;
 	}
 
+	if (binary_cb != NULL)
+	{
+		real_binary_cb = ggit_diff_binary_callback_wrapper;
+		wrapper_data.binary_cb = binary_cb;
+	}
+
 	if (hunk_cb != NULL)
 	{
 		real_hunk_cb = ggit_diff_hunk_callback_wrapper;
@@ -728,7 +792,8 @@ ggit_diff_blobs (GgitBlob              *old_blob,
 	                      new_blob ? _ggit_native_get (new_blob) : NULL,
 	                      new_as_path,
 	                      (git_diff_options *) gdiff_options,
-	                      real_file_cb, real_hunk_cb, real_line_cb,
+	                      real_file_cb, real_binary_cb,
+	                      real_hunk_cb, real_line_cb,
 	                      &wrapper_data);
 
 	if (ret != GIT_OK)
@@ -747,6 +812,8 @@ ggit_diff_blobs (GgitBlob              *old_blob,
  * @diff_options: (allow-none): a #GgitDiffOptions, or %NULL.
  * @file_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffFileCallback.
+ * @binary_cb: (allow-none) (scope call) (closure user_data):
+ *  a #GgitDiffBinaryCallback.
  * @hunk_cb: (allow-none) (scope call) (closure user_data):
  *  a #GgitDiffHunkCallback.
  * @line_cb: (allow-none) (scope call) (closure user_data):
@@ -764,15 +831,17 @@ ggit_diff_blob_to_buffer (GgitBlob              *old_blob,
                           const gchar           *buffer_as_path,
                           GgitDiffOptions       *diff_options,
                           GgitDiffFileCallback   file_cb,
+                          GgitDiffBinaryCallback binary_cb,
                           GgitDiffHunkCallback   hunk_cb,
                           GgitDiffLineCallback   line_cb,
-                          gpointer              *user_data,
+                          gpointer               user_data,
                           GError               **error)
 {
 	gint ret;
 	const git_diff_options *gdiff_options;
 	CallbackWrapperData wrapper_data;
 	git_diff_file_cb real_file_cb = NULL;
+	git_diff_binary_cb real_binary_cb = NULL;
 	git_diff_hunk_cb real_hunk_cb = NULL;
 	git_diff_line_cb real_line_cb = NULL;
 
@@ -795,6 +864,12 @@ ggit_diff_blob_to_buffer (GgitBlob              *old_blob,
 		wrapper_data.file_cb = file_cb;
 	}
 
+	if (binary_cb != NULL)
+	{
+		real_binary_cb = ggit_diff_binary_callback_wrapper;
+		wrapper_data.binary_cb = binary_cb;
+	}
+
 	if (hunk_cb != NULL)
 	{
 		real_hunk_cb = ggit_diff_hunk_callback_wrapper;
@@ -813,7 +888,8 @@ ggit_diff_blob_to_buffer (GgitBlob              *old_blob,
 	                               buffer_len,
 	                               buffer_as_path,
 	                               (git_diff_options *) gdiff_options,
-	                               real_file_cb, real_hunk_cb, real_line_cb,
+	                               real_file_cb, real_binary_cb,
+	                               real_hunk_cb, real_line_cb,
 	                               &wrapper_data);
 
 	if (ret != GIT_OK)
