@@ -218,4 +218,98 @@ ggit_oid_equal (GgitOId const *a,
 	return git_oid_cmp (&a->oid, &b->oid) == 0;
 }
 
+/**
+ * ggit_oid_is_zero:
+ * @oid: a #GgitOId.
+ *
+ * Get whether the oid contains only zeros.
+ *
+ * Returns: %TRUE if the oid contains only zeros, %FALSE otherwise.
+ */
+gboolean
+ggit_oid_is_zero (GgitOId const *oid)
+{
+	g_return_val_if_fail (oid != NULL, FALSE);
+
+	return git_oid_iszero (&oid->oid) == 1;
+}
+
+static gint
+c_to_h (gchar c)
+{
+	if (c >= '0' && c <= '9')
+	{
+		return c - '0';
+	}
+	else if (c >= 'A' && c <= 'F')
+	{
+		return 10 + (c - 'A');
+	}
+	else if (c >= 'a' && c <= 'f')
+	{
+		return 10 + (c - 'a');
+	}
+	else
+	{
+		return -1;
+	}
+}
+
+/**
+ * ggit_oid_has_prefix:
+ * @oid: a #GgitOId.
+ * @prefix: a prefix.
+ *
+ * Check whether the object id has a given prefix. Note that the prefix is
+ * specified in hexadecimal ASCII.
+ *
+ * Returns: %TRUE if the id has the given prefix, %FALSE otherwise.
+ */
+gboolean
+ggit_oid_has_prefix (GgitOId     *oid,
+                     const gchar *prefix)
+{
+	gint i;
+
+	for (i = 0; i < GIT_OID_RAWSZ; ++i)
+	{
+		gint v1;
+
+		if (*prefix == '\0')
+		{
+			return TRUE;
+		}
+
+		v1 = c_to_h (*prefix++);
+
+		if (v1 == -1)
+		{
+			return FALSE;
+		}
+
+		if (*prefix != '\0')
+		{
+			gint v2;
+
+			v2 = c_to_h (*prefix++);
+
+			if (v2 == -1)
+			{
+				return FALSE;
+			}
+
+			if (oid->oid.id[i] != (v1 << 4) + v2)
+			{
+				return FALSE;
+			}
+		}
+		else if (oid->oid.id[i] >> 4 != v1)
+		{
+			return FALSE;
+		}
+	}
+
+	return *prefix == '\0';
+}
+
 /* ex:set ts=8 noet: */
