@@ -40,6 +40,7 @@
 #include <libgit2-glib/ggit-commit.h>
 #include <libgit2-glib/ggit-tree-builder.h>
 #include <libgit2-glib/ggit-remote.h>
+#include <libgit2-glib/ggit-rebase.h>
 
 G_BEGIN_DECLS
 
@@ -264,6 +265,10 @@ void                ggit_repository_add_remote_fetch  (GgitRepository        *re
 GgitRef            *ggit_repository_get_head          (GgitRepository        *repository,
                                                        GError               **error);
 
+gboolean            ggit_repository_set_head          (GgitRepository        *repository,
+                                                       const gchar           *ref_name,
+                                                       GError               **error);
+
 GFile              *ggit_repository_discover          (GFile                 *location,
                                                        GError               **error);
 
@@ -296,6 +301,11 @@ gboolean            ggit_repository_file_status_foreach
                                                       gpointer                user_data,
                                                       GError                **error);
 
+gboolean            ggit_repository_references_foreach (GgitRepository             *repository,
+                                                        GgitReferencesCallback      callback,
+                                                        gpointer                    user_data,
+                                                        GError                    **error);
+
 gboolean            ggit_repository_references_foreach_name (GgitRepository             *repository,
                                                              GgitReferencesNameCallback  callback,
                                                              gpointer                    user_data,
@@ -454,10 +464,34 @@ gboolean            ggit_repository_note_foreach       (GgitRepository
                                                         GgitNoteCallback         callback,
                                                         gpointer                 user_data,
                                                         GError                 **error);
-gboolean           ggit_repository_path_is_ignored     (GgitRepository          *repository,
+gboolean            ggit_repository_path_is_ignored    (GgitRepository          *repository,
                                                         const gchar             *path,
                                                         GError                 **error);
 
+GgitIndex          *ggit_repository_merge_trees        (GgitRepository          *repository,
+                                                        GgitTree                *ancestor_tree,
+                                                        GgitTree                *our_tree,
+                                                        GgitTree                *their_tree,
+                                                        GgitMergeOptions        *merge_options,
+                                                        GError                 **error);
+
+GgitIndex          *ggit_repository_merge_commits      (GgitRepository          *repository,
+                                                        GgitCommit              *our_commit,
+                                                        GgitCommit              *their_commit,
+                                                        GgitMergeOptions        *merge_options,
+                                                        GError                 **error);
+
+GgitRebase         *ggit_repository_rebase_init        (GgitRepository       *repository,
+                                                        GgitAnnotatedCommit  *branch,
+                                                        GgitAnnotatedCommit  *upstream,
+                                                        GgitAnnotatedCommit  *onto,
+                                                        GgitRebaseOptions    *options,
+                                                        GError              **error);
+
+GgitRebase         *ggit_repository_rebase_open        (GgitRepository     *repository,
+                                                        GgitRebaseOptions  *options,
+                                                        GError            **error);
+
 G_DEFINE_AUTOPTR_CLEANUP_FUNC (GgitRepository, g_object_unref)
 
 G_END_DECLS
