@@ -37,10 +37,12 @@ ASSERT_ENUM (GGIT_FEATURE_THREADS, GIT_FEATURE_THREADS);
 ASSERT_ENUM (GGIT_FEATURE_HTTPS,   GIT_FEATURE_HTTPS);
 ASSERT_ENUM (GGIT_FEATURE_SSH,     GIT_FEATURE_SSH);
 
+ASSERT_ENUM (GGIT_CONFIG_LEVEL_PROGRAMDATA, GIT_CONFIG_LEVEL_PROGRAMDATA);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_SYSTEM, GIT_CONFIG_LEVEL_SYSTEM);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_XDG, GIT_CONFIG_LEVEL_XDG);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_GLOBAL, GIT_CONFIG_LEVEL_GLOBAL);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_LOCAL, GIT_CONFIG_LEVEL_LOCAL);
+ASSERT_ENUM (GGIT_CONFIG_LEVEL_APP, GIT_CONFIG_LEVEL_APP);
 ASSERT_ENUM (GGIT_CONFIG_LEVEL_HIGHEST, GIT_CONFIG_HIGHEST_LEVEL);
 
 ASSERT_ENUM (GGIT_DELTA_UNMODIFIED, GIT_DELTA_UNMODIFIED);
@@ -121,7 +123,10 @@ ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_OURS, GIT_MERGE_FILE_FAVOR_OURS);
 ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_THEIRS, GIT_MERGE_FILE_FAVOR_THEIRS);
 ASSERT_ENUM (GGIT_MERGE_FILE_FAVOR_UNION, GIT_MERGE_FILE_FAVOR_UNION);
 
-ASSERT_ENUM (GGIT_MERGE_TREE_FIND_RENAMES, GIT_MERGE_TREE_FIND_RENAMES);
+ASSERT_ENUM (GGIT_MERGE_FIND_RENAMES, GIT_MERGE_FIND_RENAMES);
+ASSERT_ENUM (GGIT_MERGE_FAIL_ON_CONFLICT, GIT_MERGE_FAIL_ON_CONFLICT);
+ASSERT_ENUM (GGIT_MERGE_SKIP_REUC, GIT_MERGE_SKIP_REUC);
+ASSERT_ENUM (GGIT_MERGE_NO_RECURSIVE, GIT_MERGE_NO_RECURSIVE);
 
 ASSERT_ENUM (GGIT_REBASE_OPERATION_PICK, GIT_REBASE_OPERATION_PICK);
 ASSERT_ENUM (GGIT_REBASE_OPERATION_REWORD, GIT_REBASE_OPERATION_REWORD);
