@@ -21,6 +21,7 @@
 #ifndef __GGIT_H__
 #define __GGIT_H__
 
+#include <libgit2-glib/ggit-annotated-commit.h>
 #include <libgit2-glib/ggit-blob.h>
 #include <libgit2-glib/ggit-blob-output-stream.h>
 #include <libgit2-glib/ggit-branch-enumerator.h>
@@ -55,6 +56,9 @@
 #include <libgit2-glib/ggit-object.h>
 #include <libgit2-glib/ggit-oid.h>
 #include <libgit2-glib/ggit-patch.h>
+#include <libgit2-glib/ggit-rebase-operation.h>
+#include <libgit2-glib/ggit-rebase-options.h>
+#include <libgit2-glib/ggit-rebase.h>
 #include <libgit2-glib/ggit-ref.h>
 #include <libgit2-glib/ggit-reflog-entry.h>
 #include <libgit2-glib/ggit-reflog.h>
